########
Examples
########

Example uses of the :ref:`Kubernetes <mod-k8s>` module


******************
CloudFormation EKS
******************

To view an example using an EKS cluster deployed with CloudFormation, run ``runway gen-sample k8s-cfn-repo`` in any directory.
This will create a ``k8s-cfn-infrastructure/`` directory in your current working directory containing a ``runway.yml`` file, some modules that can be deployed, and a ``README.md`` that provides instructions on how to work with the example code.


*************
Terraform EKS
*************

To view an example using an EKS cluster deployed with Terraform, run ``runway gen-sample k8s-tf-repo`` in any directory.
This will create a ``k8s-tf-infrastructure/`` directory in your current working directory containing a ``runway.yml`` file, some modules that can be deployed, and a ``README.md`` that provides instructions on how to work with the example code.
